@@ -29,8 +29,8 @@ typedef enum {
     ISN_STORE,	    // pop into local variable isn_arg.number
     ISN_STOREV,	    // pop into v: variable isn_arg.number
     ISN_STOREG,	    // pop into global variable isn_arg.string
-    ISN_STORES,	    // pop into scirpt variable isn_arg.loadstore
-    ISN_STORESCRIPT, // pop into scirpt variable isn_arg.script
+    ISN_STORES,	    // pop into script variable isn_arg.loadstore
+    ISN_STORESCRIPT, // pop into script variable isn_arg.script
     ISN_STOREOPT,   // pop into option isn_arg.string
     ISN_STOREENV,    // pop into environment variable isn_arg.string
     ISN_STOREREG,    // pop into register isn_arg.number
@@ -46,7 +46,6 @@ typedef enum {
     ISN_PUSHS,		// push string isn_arg.string
     ISN_PUSHBLOB,	// push blob isn_arg.blob
     ISN_PUSHFUNC,	// push func isn_arg.string
-    ISN_PUSHPARTIAL,	// push partial ?
     ISN_PUSHCHANNEL,	// push channel isn_arg.channel
     ISN_PUSHJOB,	// push channel isn_arg.job
     ISN_NEWLIST,	// push list from stack items, size is isn_arg.number
@@ -57,6 +56,7 @@ typedef enum {
     ISN_DCALL,	    // call def function isn_arg.dfunc
     ISN_UCALL,	    // call user function or funcref/partial isn_arg.ufunc
     ISN_PCALL,	    // call partial, use isn_arg.pfunc
+    ISN_PCALL_END,  // cleanup after ISN_PCALL with cpf_top set
     ISN_RETURN,	    // return, result is on top of stack
     ISN_FUNCREF,    // push a function ref to dfunc isn_arg.number
 
@@ -91,7 +91,6 @@ typedef enum {
     ISN_COMPARELIST,
     ISN_COMPAREDICT,
     ISN_COMPAREFUNC,
-    ISN_COMPAREPARTIAL,
     ISN_COMPAREANY,
 
     // expression operations
@@ -190,7 +189,7 @@ typedef struct {
 
 // arguments to ISN_LOADS and ISN_STORES
 typedef struct {
-    char_u	*ls_name;	// variable name
+    char_u	*ls_name;	// variable name (with s: for ISN_STORES)
     int		ls_sid;		// script ID
 } loadstore_T;
 
@@ -203,7 +202,7 @@ typedef struct {
 /*
  * Instruction
  */
-typedef struct {
+struct isn_S {
     isntype_T	isn_type;
     int		isn_lnum;
     union {
@@ -231,7 +230,7 @@ typedef struct {
 	loadstore_T	    loadstore;
 	script_T	    script;
     } isn_arg;
-} isn_T;
+};
 
 /*
  * Info about a function defined with :def.  Used in "def_functions".
